@@ -40,7 +40,7 @@ class MigrationPolicy(Resource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             spec = self.res.setdefault("spec", {})
             selectors = spec.setdefault("selectors", {})
 
